Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(816)

Unified Diff: sandbox/win/src/policy_opcodes_unittest.cc

Issue 1538283002: Switch to standard integer types in sandbox/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: macros Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sandbox/win/src/policy_low_level_unittest.cc ('k') | sandbox/win/src/policy_target.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sandbox/win/src/policy_opcodes_unittest.cc
diff --git a/sandbox/win/src/policy_opcodes_unittest.cc b/sandbox/win/src/policy_opcodes_unittest.cc
index 954aa445dfd808a72411062dc70db403b9dc8399..f8c210e8762db8c16ad95dd0ae62ccc37a0411e6 100644
--- a/sandbox/win/src/policy_opcodes_unittest.cc
+++ b/sandbox/win/src/policy_opcodes_unittest.cc
@@ -2,10 +2,13 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "sandbox/win/src/sandbox_types.h"
-#include "sandbox/win/src/sandbox_nt_types.h"
-#include "sandbox/win/src/policy_engine_params.h"
+#include <stddef.h>
+#include <stdint.h>
+
#include "sandbox/win/src/policy_engine_opcodes.h"
+#include "sandbox/win/src/policy_engine_params.h"
+#include "sandbox/win/src/sandbox_nt_types.h"
+#include "sandbox/win/src/sandbox_types.h"
#include "testing/gtest/include/gtest/gtest.h"
@@ -45,7 +48,7 @@ TEST(PolicyEngineTest, ParameterSetTest) {
// Test that we can store and retrieve a void pointer:
const void* result1 =0;
- uint32 result2 = 0;
+ uint32_t result2 = 0;
EXPECT_TRUE(pset1.Get(&result1));
EXPECT_TRUE(pv1 == result1);
EXPECT_FALSE(pset1.Get(&result2));
@@ -53,8 +56,8 @@ TEST(PolicyEngineTest, ParameterSetTest) {
EXPECT_TRUE(pv2 == result1);
EXPECT_FALSE(pset2.Get(&result2));
- // Test that we can store and retrieve a uint32:
- uint32 number = 12747;
+ // Test that we can store and retrieve a uint32_t:
+ uint32_t number = 12747;
ParameterSet pset3 = ParamPickerMake(number);
EXPECT_FALSE(pset3.Get(&result1));
EXPECT_TRUE(pset3.Get(&result2));
@@ -181,8 +184,8 @@ TEST(PolicyEngineTest, OpcodeMakerCase2) {
TEST(PolicyEngineTest, IntegerOpcodes) {
const wchar_t* txt = L"abcdef";
- uint32 num1 = 42;
- uint32 num2 = 113377;
+ uint32_t num1 = 42;
+ uint32_t num2 = 113377;
ParameterSet pp_wrong1 = ParamPickerMake(txt);
ParameterSet pp_num1 = ParamPickerMake(num1);
@@ -221,7 +224,7 @@ TEST(PolicyEngineTest, LogicalOpcodes) {
char memory[kOpcodeMemory];
OpcodeFactory opcode_maker(memory, sizeof(memory));
- uint32 num1 = 0x10100702;
+ uint32_t num1 = 0x10100702;
ParameterSet pp_num1 = ParamPickerMake(num1);
PolicyOpcode* op_and1 =
« no previous file with comments | « sandbox/win/src/policy_low_level_unittest.cc ('k') | sandbox/win/src/policy_target.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698